@@ -2,9 +2,6 @@ require 'plasma_applet'
 
 module Tiger
   class Main < PlasmaScripting::Applet
-
-    slots 'void dataUpdated(QString, Plasma::DataEngine::Data)'
-
     def initialize(parent, args = nil)
       super
     end
@@ -12,12 +9,7 @@ module Tiger
     def init
       @svg = Plasma::Svg.new(self)
       @svg.imagePath = 'widgets/tiger'
-      timeEngine = dataEngine("time")
-      timeEngine.connectSource("Local", self, 6000)
-    end
-
-    def dataUpdated(name, data)
-      puts ("In DataUpdated name: %s data: %s", [name, data["Time"].toTime.toString]);
+#      Qt::Internal::setDebug Qt::QtDebugChannel::QTDB_VIRTUAL
     end
 
     def paintInterface(painter, option, contentsRect)
